@@ -27,14 +27,10 @@
  *
  * Useful stuff called from several different FireWire objects.
  */
- 
-// public
-#import <IOKit/firewire/IOFireWireFamilyCommon.h>
-#import <IOKit/firewire/IOFWUtils.h>
-
-// system
 #import <IOKit/assert.h>
 #import <IOKit/IOLib.h>
+#import <IOKit/firewire/IOFireWireFamilyCommon.h>
+#import "IOFWUtils.h"
 
 ////////////////////////////////////////////////////////////////////////////////
 //
