@@ -27,18 +27,12 @@
  *
  */
 
-// public
-#import <IOKit/firewire/IOFireWireNub.h>
-#import <IOKit/firewire/IOFireWireController.h>
-#import <IOKit/firewire/IOConfigDirectory.h>
-
-// protected
-#import <IOKit/firewire/IOFireWireLink.h>
-
-// private
 #import "IOFireWireUserClient.h"
+#import "IOFireWireLink.h"
+#import "IOFireWireNub.h"
+#import "IOFireWireController.h"
+#import "IOConfigDirectory.h"
 
-// system
 #import <IOKit/assert.h>
 #import <IOKit/IOMessage.h>
 
@@ -78,9 +72,6 @@ void IOFireWireNub::free()
 	if( fConfigDirectorySet )
 		fConfigDirectorySet->release();
 		
-    if(fControl)
-        fControl->release();
-
     IOService::free();
 }
 
