@@ -42,7 +42,7 @@ namespace IOFireWireLib {
 	//
 	// ============================================================
 	
-	ConfigDirectory::ConfigDirectory( IUnknownVTbl* interface, Device& userclient, FWKernConfigDirectoryRef inKernConfigDirectoryRef)
+	ConfigDirectory::ConfigDirectory( IUnknownVTbl* interface, Device& userclient, KernConfigDirectoryRef inKernConfigDirectoryRef)
 	: IOFireWireIUnknown( interface ),
 	mUserClient( userclient ),
 	mKernConfigDirectoryRef( inKernConfigDirectoryRef )
@@ -54,7 +54,7 @@ namespace IOFireWireLib {
 	: IOFireWireIUnknown( interface ),
 	mUserClient( userclient )
 	{	
-		IOReturn err = IOConnectMethodScalarIScalarO(mUserClient.GetUserClientConnection(), kFWConfigDirectoryCreate, 0, 1, & mKernConfigDirectoryRef) ;
+		IOReturn err = IOConnectMethodScalarIScalarO(mUserClient.GetUserClientConnection(), kConfigDirectoryCreate, 0, 1, & mKernConfigDirectoryRef) ;
 		if (err)
 			throw ;//Exception::IOReturn(err) ;	//!!!
 
@@ -63,12 +63,9 @@ namespace IOFireWireLib {
 		
 	ConfigDirectory::~ConfigDirectory()
 	{
-		IOReturn err = IOConnectMethodScalarIScalarO(
-					mUserClient.GetUserClientConnection(),
-					kFWConfigDirectoryRelease,
-					1,
-					0,
-					mKernConfigDirectoryRef ) ;
+		IOReturn err = kIOReturnSuccess;
+		err = IOConnectMethodScalarIScalarO( mUserClient.GetUserClientConnection(), kConfigDirectoryRelease,
+				1, 0, mKernConfigDirectoryRef ) ;
 		IOFireWireLibLogIfErr_(err, "%s %u: release config dir failed err=%x\n", __FILE__, __LINE__, err) ;
 	
 		mUserClient.Release() ;
@@ -83,22 +80,17 @@ namespace IOFireWireLib {
 	IOReturn
 	ConfigDirectory::GetKeyType(int key, IOConfigKeyType& type)
 	{
-		return IOConnectMethodScalarIScalarO(
-					mUserClient.GetUserClientConnection(),
-					kFWConfigDirectoryGetKeyType,
-					1,
-					1,
-					key,
-					& type) ;
+		return IOConnectMethodScalarIScalarO( mUserClient.GetUserClientConnection(), kConfigDirectoryGetKeyType,
+					1, 1, key, & type) ;
 	}
 	
 	IOReturn
 	ConfigDirectory::GetKeyValue(int key, UInt32 &value, CFStringRef*& text)
 	{
-		FWKernOSStringRef	kernelStringRef ;
+		KernOSStringRef	kernelStringRef ;
 		UInt32				stringLen ;
 		IOReturn result = ::IOConnectMethodScalarIScalarO( mUserClient.GetUserClientConnection(),
-				kFWConfigDirectoryGetKeyValue_UInt32, 3, 3, mKernConfigDirectoryRef, key, text != nil,
+				kConfigDirectoryGetKeyValue_UInt32, 3, 3, mKernConfigDirectoryRef, key, text != nil,
 				& value, & kernelStringRef, & stringLen) ;
 	
 		if (text && (kIOReturnSuccess == result))
@@ -110,11 +102,11 @@ namespace IOFireWireLib {
 	IOReturn
 	ConfigDirectory::GetKeyValue(int key, CFDataRef* value, CFStringRef*& text)
 	{
-		FWGetKeyValueDataResults results ;
+		GetKeyValueDataResults results ;
 		IOByteCount	resultsSize = sizeof(results) ;
 		
 		IOReturn error = IOConnectMethodScalarIStructureO( mUserClient.GetUserClientConnection(), 
-				kFWConfigDirectoryGetKeyValue_Data, 3, & resultsSize, mKernConfigDirectoryRef, key, text != nil,
+				kConfigDirectoryGetKeyValue_Data, 3, & resultsSize, mKernConfigDirectoryRef, key, text != nil,
 				& results ) ;
 	
 		if ( text && (kIOReturnSuccess == error))
@@ -128,10 +120,10 @@ namespace IOFireWireLib {
 	IOReturn
 	ConfigDirectory::GetKeyValue(int key, DirRef& value, REFIID iid, CFStringRef*& text)
 	{
-		FWKernOSStringRef			kernelStringRef ;
-		FWKernConfigDirectoryRef	kernelDirectoryRef ;
+		KernOSStringRef			kernelStringRef ;
+		KernConfigDirectoryRef	kernelDirectoryRef ;
 		UInt32						stringLen ;
-		IOReturn result = IOConnectMethodScalarIScalarO( mUserClient.GetUserClientConnection(), kFWConfigDirectoryGetKeyValue_ConfigDirectory,
+		IOReturn result = IOConnectMethodScalarIScalarO( mUserClient.GetUserClientConnection(), kConfigDirectoryGetKeyValue_ConfigDirectory,
 				3, 3, mKernConfigDirectoryRef, key, text != nil, & kernelDirectoryRef, & kernelStringRef, & stringLen ) ;
 	
 		IUnknownVTbl**	iUnknown = nil ;
@@ -159,10 +151,10 @@ namespace IOFireWireLib {
 	IOReturn
 	ConfigDirectory::GetKeyOffset(int key, FWAddress& value, CFStringRef*& text)
 	{
-		FWGetKeyOffsetResults results ;
+		GetKeyOffsetResults results ;
 		IOByteCount resultsSize = sizeof(results) ;
 
-		IOReturn error = IOConnectMethodScalarIStructureO( mUserClient.GetUserClientConnection(), kFWConfigDirectoryGetKeyOffset_FWAddress,
+		IOReturn error = ::IOConnectMethodScalarIStructureO( mUserClient.GetUserClientConnection(), kConfigDirectoryGetKeyOffset_FWAddress,
 				3, & resultsSize, mKernConfigDirectoryRef, key, text != nil, & results ) ;
 		
 		value = results.address ;
@@ -174,14 +166,14 @@ namespace IOFireWireLib {
 	}
 	
 	IOReturn
-	ConfigDirectory::GetKeyValue(int key, FWKernConfigDirectoryRef& value)
+	ConfigDirectory::GetKeyValue(int key, KernConfigDirectoryRef& value)
 	{
-		FWKernOSStringRef			kernelStringRef ;
-		FWKernConfigDirectoryRef	kernelDirectoryRef ;
+		KernOSStringRef			kernelStringRef ;
+		KernConfigDirectoryRef	kernelDirectoryRef ;
 		UInt32						stringLen ;
 		IOReturn result = IOConnectMethodScalarIScalarO(
 								mUserClient.GetUserClientConnection(),
-								kFWConfigDirectoryGetKeyValue_ConfigDirectory,
+								kConfigDirectoryGetKeyValue_ConfigDirectory,
 								3,
 								3,
 								mKernConfigDirectoryRef,
@@ -197,57 +189,33 @@ namespace IOFireWireLib {
 	IOReturn
 	ConfigDirectory::GetIndexType(int index, IOConfigKeyType &type)
 	{
-		return IOConnectMethodScalarIScalarO(
-					mUserClient.GetUserClientConnection(),
-					kFWConfigDirectoryGetIndexType,
-					2,
-					1,
-					mKernConfigDirectoryRef,
-					index,
-					& type) ;
+		return ::IOConnectMethodScalarIScalarO( mUserClient.GetUserClientConnection(), kConfigDirectoryGetIndexType,
+					2, 1, mKernConfigDirectoryRef, index, & type) ;
 	}
 	
 	IOReturn
 	ConfigDirectory::GetIndexKey(int index, int &key)
 	{
-		return IOConnectMethodScalarIScalarO(
-					mUserClient.GetUserClientConnection(),
-					kFWConfigDirectoryGetIndexKey,
-					2,
-					1,
-					mKernConfigDirectoryRef,
-					index,
-					& key) ;
+		return ::IOConnectMethodScalarIScalarO( mUserClient.GetUserClientConnection(), kConfigDirectoryGetIndexKey,
+					2, 1, mKernConfigDirectoryRef, index, & key) ;
 	}
 	
 	IOReturn
 	ConfigDirectory::GetIndexValue(int index, UInt32& value)
 	{
-		return IOConnectMethodScalarIScalarO(
-					mUserClient.GetUserClientConnection(),
-					kFWConfigDirectoryGetIndexValue_UInt32,
-					2,
-					1,
-					mKernConfigDirectoryRef,
-					index,
-					& value) ;
+		return ::IOConnectMethodScalarIScalarO( mUserClient.GetUserClientConnection(), 
+				kConfigDirectoryGetIndexValue_UInt32, 2, 1, mKernConfigDirectoryRef, index, & value) ;
 	}
 	
 		
 	IOReturn
 	ConfigDirectory::GetIndexValue(int index, CFDataRef* value)
 	{
-		FWKernOSDataRef	dataRef ;
+		KernOSDataRef	dataRef ;
 		IOByteCount		dataLen ;
-		IOReturn result = IOConnectMethodScalarIScalarO(
-								mUserClient.GetUserClientConnection(),
-								kFWConfigDirectoryGetIndexValue_Data,
-								2,
-								2,
-								mKernConfigDirectoryRef,
-								index,
-								& dataRef,
-								& dataLen) ;
+		IOReturn result = ::IOConnectMethodScalarIScalarO( mUserClient.GetUserClientConnection(),
+								kConfigDirectoryGetIndexValue_Data, 2, 2, mKernConfigDirectoryRef, index, 
+								& dataRef, & dataLen) ;
 	
 		if (kIOReturnSuccess == result)
 			result = mUserClient.CreateCFDataWithOSDataRef(dataRef, dataLen, value) ;
@@ -258,17 +226,11 @@ namespace IOFireWireLib {
 	IOReturn
 	ConfigDirectory::GetIndexValue(int index, CFStringRef* value)
 	{
-		FWKernOSStringRef	stringRef ;
+		KernOSStringRef		stringRef ;
 		UInt32				stringLen ;
-		IOReturn result = IOConnectMethodScalarIScalarO(
-								mUserClient.GetUserClientConnection(),
-								kFWConfigDirectoryGetIndexValue_String,
-								2,
-								2,
-								mKernConfigDirectoryRef,
-								index,
-								& stringRef,
-								& stringLen) ;
+		IOReturn result = ::IOConnectMethodScalarIScalarO( mUserClient.GetUserClientConnection(),
+								kConfigDirectoryGetIndexValue_String, 2, 2, mKernConfigDirectoryRef,
+								index, & stringRef, & stringLen) ;
 	
 		if (kIOReturnSuccess == result)
 			result = mUserClient.CreateCFStringWithOSStringRef(stringRef, stringLen, value) ;
@@ -277,24 +239,18 @@ namespace IOFireWireLib {
 	}
 	
 	IOReturn
-	ConfigDirectory::GetIndexValue(int index, FWKernConfigDirectoryRef& value)
+	ConfigDirectory::GetIndexValue(int index, KernConfigDirectoryRef& value)
 	{
-		return IOConnectMethodScalarIScalarO(
-						mUserClient.GetUserClientConnection(),
-						kFWConfigDirectoryGetIndexValue_ConfigDirectory,
-						2,
-						1,
-						mKernConfigDirectoryRef,
-						index,
-						& value) ;
+		return ::IOConnectMethodScalarIScalarO( mUserClient.GetUserClientConnection(), 
+				kConfigDirectoryGetIndexValue_ConfigDirectory, 2, 1, mKernConfigDirectoryRef, index, & value) ;
 	}
 	
 	IOReturn
 	ConfigDirectory::GetIndexValue(int index, IOFireWireLibConfigDirectoryRef& value, REFIID iid)
 	{
-		FWKernConfigDirectoryRef	directoryRef ;
-		IOReturn result = IOConnectMethodScalarIScalarO(mUserClient.GetUserClientConnection(), kFWConfigDirectoryGetIndexValue_ConfigDirectory,
-									2, 1, mKernConfigDirectoryRef, index, & directoryRef) ;
+		KernConfigDirectoryRef	directoryRef ;
+		IOReturn result = IOConnectMethodScalarIScalarO(mUserClient.GetUserClientConnection(), 
+				kConfigDirectoryGetIndexValue_ConfigDirectory, 2, 1, mKernConfigDirectoryRef, index, & directoryRef) ;
 	
 		IUnknownVTbl** iUnknown ;
 		if (kIOReturnSuccess == result)
@@ -320,7 +276,7 @@ namespace IOFireWireLib {
 	{
 		UInt32 addressHi ;
 		UInt32 addressLo ;
-		IOReturn result = IOConnectMethodScalarIScalarO(mUserClient.GetUserClientConnection(), kFWConfigDirectoryGetIndexOffset_FWAddress, 2, 2, 
+		IOReturn result = IOConnectMethodScalarIScalarO(mUserClient.GetUserClientConnection(), kConfigDirectoryGetIndexOffset_FWAddress, 2, 2, 
 								mKernConfigDirectoryRef, index, & addressHi, & addressLo) ;
 		
 		value.nodeID = addressHi>>16 ;
@@ -333,42 +289,42 @@ namespace IOFireWireLib {
 	IOReturn
 	ConfigDirectory::GetIndexOffset(int index, UInt32& value)
 	{
-		return IOConnectMethodScalarIScalarO(mUserClient.GetUserClientConnection(), kFWConfigDirectoryGetIndexOffset_UInt32, 2, 1,
+		return IOConnectMethodScalarIScalarO(mUserClient.GetUserClientConnection(), kConfigDirectoryGetIndexOffset_UInt32, 2, 1,
 						mKernConfigDirectoryRef, index, & value) ;
 	}
 	
 	IOReturn
 	ConfigDirectory::GetIndexEntry(int index, UInt32 &value)
 	{
-		return IOConnectMethodScalarIScalarO(mUserClient.GetUserClientConnection(), kFWConfigDirectoryGetIndexEntry, 2, 1, 
+		return IOConnectMethodScalarIScalarO(mUserClient.GetUserClientConnection(), kConfigDirectoryGetIndexEntry, 2, 1, 
 						mKernConfigDirectoryRef, index, & value) ;
 	}
 	
 	IOReturn
 	ConfigDirectory::GetSubdirectories(io_iterator_t *outIterator)
 	{
-		return IOConnectMethodScalarIScalarO(mUserClient.GetUserClientConnection(), kFWConfigDirectoryGetSubdirectories, 1, 1,
+		return IOConnectMethodScalarIScalarO(mUserClient.GetUserClientConnection(), kConfigDirectoryGetSubdirectories, 1, 1,
 						mKernConfigDirectoryRef, outIterator) ;
 	}
 	
 	IOReturn
 	ConfigDirectory::GetKeySubdirectories(int key, io_iterator_t *outIterator)
 	{
-		return IOConnectMethodScalarIScalarO(mUserClient.GetUserClientConnection(), kFWConfigDirectoryGetKeySubdirectories, 2, 1,
+		return IOConnectMethodScalarIScalarO(mUserClient.GetUserClientConnection(), kConfigDirectoryGetKeySubdirectories, 2, 1,
 						mKernConfigDirectoryRef, key, outIterator) ;
 	}
 	
 	IOReturn
 	ConfigDirectory::GetType(int *outType)
 	{
-		return IOConnectMethodScalarIScalarO(mUserClient.GetUserClientConnection(), kFWConfigDirectoryGetType, 1, 1, mKernConfigDirectoryRef,
+		return IOConnectMethodScalarIScalarO(mUserClient.GetUserClientConnection(), kConfigDirectoryGetType, 1, 1, mKernConfigDirectoryRef,
 						outType) ;
 	}
 	
 	IOReturn 
 	ConfigDirectory::GetNumEntries(int *outNumEntries)
 	{
-		return IOConnectMethodScalarIScalarO(mUserClient.GetUserClientConnection(), kFWConfigDirectoryGetNumEntries, 1, 1,
+		return IOConnectMethodScalarIScalarO(mUserClient.GetUserClientConnection(), kConfigDirectoryGetNumEntries, 1, 1,
 						mKernConfigDirectoryRef, outNumEntries) ;
 	}
 	
@@ -379,7 +335,7 @@ namespace IOFireWireLib {
 	// ============================================================
 	
 #pragma mark -
-	ConfigDirectoryCOM::ConfigDirectoryCOM( Device& inUserClient, FWKernConfigDirectoryRef inDirRef )
+	ConfigDirectoryCOM::ConfigDirectoryCOM( Device& inUserClient, KernConfigDirectoryRef inDirRef )
 	: ConfigDirectory( reinterpret_cast<IUnknownVTbl*>( & sInterface ), inUserClient, inDirRef)
 	{
 	}
@@ -394,7 +350,7 @@ namespace IOFireWireLib {
 	}
 	
 	IUnknownVTbl**
-	ConfigDirectoryCOM::Alloc( Device& inUserClient, FWKernConfigDirectoryRef inDirRef )
+	ConfigDirectoryCOM::Alloc( Device& inUserClient, KernConfigDirectoryRef inDirRef )
 	{
 		ConfigDirectoryCOM*	me = nil ;
 		
