@@ -28,11 +28,8 @@
  *
  */
 
-// public
-#import <IOKit/firewire/IOFireWireLib.h>
-#import <IOKit/firewire/IOFireWireLibIsoch.h>
-
-// private
+#import "IOFireWireLib.h"
+#import "IOFireWireLibIsoch.h"
 #import "IOFireWireLibPriv.h"
 
 namespace IOFireWireLib {
